@@ -1,7 +1,12 @@
 from .queries import get_db_from,fetch_any_combo
 from .call_log_data import get_signature_from_log_id
-def get_transaction_from(columnNames='*',searchColumn=None,searchValue=None,count=False):
-    return get_db_from('transactions',columnNames=columnNames,searchColumn=searchColumn,searchValue=searchValue)
+def get_transaction_from(columnNames=None,searchColumn=None,searchValue=None,count=False):
+    columnNames = columnNames or '*'
+    return get_db_from(tableName='transactions',
+                       columnNames=columnNames,
+                       searchColumn=searchColumn,
+                       searchValue=searchValue,
+                       count=count)
 def count_transactions_for_pair(pair_id):
     return get_transaction_from(searchColumn="pair_id",searchValue=pair_id,count=True)
 def get_transaction_from_signature(signature):
